@@ -262,6 +262,8 @@ class Interaction:
         The arguments that were passed
     created_at : :class:`datetime.datetime`
         Then interaction was created
+    expired : :class:`bool:
+        Whether the interaction token is still valid
     '''
     def __init__(self, client, payload: dict):
         state = client.user._state
@@ -291,8 +293,12 @@ class Interaction:
             guild=self.guild,
             state=state
         )
+        self._webhook = discord.Webhook(
+            {"id": self.client.user.id, "type": 1, "token": self.token},
+            adapter=discord.AsyncWebhookAdapter(self.client.http._HTTPClient__session)
+        )
         self.editable = False
-        self.__expired = False
+        self.__sent = False
     @property
     def channel(self):
         if self._channel is None:
@@ -309,9 +315,10 @@ class Interaction:
         return datetime.datetime.fromtimestamp(((self.id >> 22) + DISCORD_EPOCH) / 1000)
     @property
     def expired(self):
-        if self.__expired: return True
-        self.__expired = datetime.datetime.utcnow() - self.created_at > datetime.timedelta(minutes=15)
-        return self.__expired
+        if self.__sent:
+            return datetime.datetime.utcnow() - self.created_at > datetime.timedelta(minutes=15)
+        else:
+            return datetime.datetime.utcnow() - self.created_at > datetime.timedelta(seconds=3)
 
     def get(self, name: str, default=None):
         """Equivalent to :class:`InteractionData.get`"""
@@ -372,8 +379,8 @@ class Interaction:
         message : :class:`discord.Message` | ``None``
             The response message that has been sent or ``None`` if the message is ephemeral
         '''
-        # If expired, use TextChannel.send instead
-        if self.expired:
+        # Sometimes we have to use TextChannel.send() instead
+        if self.__sent or self.expired:
             return await self.channel.send(
                 content=content, embed=embed,
                 file=file, files=files,
@@ -385,10 +392,7 @@ class Interaction:
         # Which callback type is it
         if type is None:
             if is_empty_message:
-                if hide_user_input:
-                    type = 2
-                else:
-                    type = 5
+                type = 2 if hide_user_input else 5
             elif hide_user_input:
                 type = 3
             else:
@@ -440,10 +444,14 @@ class Interaction:
             ),
             json=_json
         )
-        self.__expired = True
+        self.__sent = True
+        # Type-5 responses are always editable
+        if type == 5:
+            self.editable = True
+            return None
         # Ephemeral messages aren't stored and can't be deleted or edited
-        # Same for empty type-1 & type-5 messages
-        if ephemeral or is_empty_message:
+        # Same for type-1 and type-2 messages
+        if ephemeral or type in (1, 2):
             return None
         self.editable = True
         if delete_after is not None:
@@ -471,7 +479,7 @@ class Interaction:
             The message that was edited
         '''
         if not self.editable:
-            raise TypeError("There's nothing to edit. Send a reply first.")
+            raise TypeError("There's nothing to edit or the message is ephemeral.")
         # Form JSON params
         data = {}
         if content is not None:
@@ -535,6 +543,21 @@ class Interaction:
         except:
             pass
 
+    async def followup(self, content=None, *,   embed=None, embeds=None,
+                                                file=None, files=None,
+                                                tts=None, allowed_mentions=None):
+        r = await self._webhook.send(
+            content=content, tts=tts,
+            file=file, files=files,
+            embed=embed, embeds=embeds,
+            allowed_mentions=allowed_mentions
+        )
+        return discord.Message(
+            state=self.client.user._state,
+            channel=self.channel,
+            data=r
+        )
+
     send = reply
 
 
